@@ -24,15 +24,17 @@
 #'
 #' @details
 #'
+#' See the \href{http://rmarkdown.rstudio.com/markdown_document_format.html}{online
+#' documentation} for additional details on using the \code{md_document} format.
+#'
 #' R Markdown documents can have optional metadata that is used to generate a
 #' document header that includes the title, author, and date. For more details
 #' see the documentation on R Markdown \link[=rmd_metadata]{metadata}.
 #'
 #' R Markdown documents also support citations. You can find more information on
-#' the markdown syntax for citations within the pandoc documentation on
-#' \href{http://johnmacfarlane.net/pandoc/demo/example19/Citations.html}{citations}
-#' and
-#' \href{http://johnmacfarlane.net/pandoc/demo/example19/Footnotes.html}{footnotes}.
+#' the markdown syntax for citations in the
+#' \href{http://rmarkdown.rstudio.com/authoring_bibliographies_and_citations.html}{Bibliographies
+#' and Citations} article in the online documentation.
 #'
 #' @examples
 #' \dontrun{
@@ -41,7 +43,7 @@
 #'
 #' render("input.Rmd", md_document())
 #'
-#' render("input.Rmd", md_document(variant = "github_flavored_markdown"))
+#' render("input.Rmd", md_document(variant = "markdown_github"))
 #' }
 #'
 #' @export
@@ -54,6 +56,7 @@ md_document <- function(variant = "markdown_strict",
                         fig_retina = NULL,
                         dev = 'png',
                         includes = NULL,
+                        md_extensions = NULL,
                         pandoc_args = NULL) {
 
   # base pandoc options for all markdown output
@@ -89,7 +92,7 @@ md_document <- function(variant = "markdown_strict",
   output_format(
     knitr = knitr_options_html(fig_width, fig_height, fig_retina, FALSE, dev),
     pandoc = pandoc_options(to = variant,
-                            from = from_rmarkdown(),
+                            from = from_rmarkdown(extensions = md_extensions),
                             args = args),
     clean_supporting = FALSE,
     post_processor = post_processor
